@@ -81,8 +81,8 @@ static char *function_names[NUM_FUNCTIONS + 1] = {
    "Double Snap", "Halve Snap", "Pan Left", "Pan Right", "Pan Up",
    "Pan Down", "Write", "Rotate", "Flip X", "Flip Y", "Snap", "Snap To",
    "Pop", "Push", "Delete", "Select", "Box", "Arc", "Text",
-   "Exchange", "Copy", "Join", "Unjoin", "Spline", "Edit",
-   "Undelete", "Select Save", "Unselect", "Dashed", "Dotted",
+   "Exchange", "Copy", "Move", "Join", "Unjoin", "Spline", "Edit",
+   "Undo", "Redo", "Select Save", "Unselect", "Dashed", "Dotted",
    "Solid", "Prompt", "Dot", "Wire", "Start", "Finish", "Cancel",
    "Nothing", "Exit",
    "Netlist", "Swap", "Pin Label", "Pin Global", "Info Label",
@@ -619,7 +619,8 @@ void default_keybindings()
    add_binding(XK_J, XCF_Unjoin);
    add_binding(XK_s, XCF_Spline);
    add_binding(XK_e, XCF_Edit);
-   add_binding(XK_u, XCF_Undelete);
+   add_binding(XK_u, XCF_Undo);
+   add_binding(XK_U, XCF_Redo);
    add_binding(XK_M, XCF_Select_Save);
    add_binding(XK_m, XCF_Select_Save);
    add_binding(XK_x, XCF_Unselect);
