@@ -204,7 +204,7 @@ menustruct PolyMenu[] = {
 
 menustruct FilterMenu[] = {
 	{"Labels", setaction(selectfilter, Number(LABEL))},
-	{"Objects", setaction(selectfilter, Number(OBJECT))},
+	{"Objects", setaction(selectfilter, Number(OBJINST))},
 	{"Polygons", setaction(selectfilter, Number(POLYGON))},
 	{"Arcs", setaction(selectfilter, Number(ARC))},
 	{"Splines", setaction(selectfilter, Number(SPLINE))},
@@ -286,6 +286,9 @@ menustruct FileMenu[] = {
 	{"Read Xcircuit File", action(getfile, Number(NORMAL))},
 	{"Import Xcircuit PS", action(getfile, Number(IMPORT))},
 	{"Import background PS", action(getfile, Number(PSBKGROUND))},
+#ifdef ASG
+	{"Import SPICE deck", action(getfile, Number(IMPORTSPICE))},
+#endif
 	{"Execute script", action(getfile, Number(SCRIPT))},
 	{"Write Xcircuit PS (W)", action(outputpopup, NULL)},
 	{" ", noaction},
@@ -316,8 +319,10 @@ menustruct OptionMenu[] = {
 };
 
 menustruct EditMenu[] = {
+	{"Undo (u)", action(undo_call, NULL)},
+	{"Redo (U)", action(redo_call, NULL)},
+	{" ", noaction},
 	{"Delete (d)", action(startdelete, NULL)},
-	{"Undelete (u)", action(xc_undelete, Number(DRAW))},
 	{"Copy (c)", action(startcopy, NULL)},
 	{"Edit (e)", action(startedit, NULL)},
 	{"Rotate/Flip", submenu(RotateMenu)},
